@@ -7,7 +7,7 @@ Attean::API::Plan - Query plan
 
 =head1 VERSION
 
-This document describes Attean::API::Plan version 0.004_01
+This document describes Attean::API::Plan version 0.007
 
 =head1 DESCRIPTION
 
@@ -23,8 +23,9 @@ The following methods are required by the L<Attean::API::Plan> role:
 
 use Type::Tiny::Role;
 
-package Attean::API::Plan 0.004 {
+package Attean::API::Plan 0.007 {
 	use Moo::Role;
+	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ArrayRef CodeRef Str Object InstanceOf Bool Num);
 	use namespace::clean;
 	
@@ -74,9 +75,44 @@ package Attean::API::Plan 0.004 {
 		my $impl	= $self->impl(@_);
 		return $impl->();
 	}
+
+	sub in_scope_variables_union {
+		my @plans	= grep { blessed($_) } @_;
+		my %vars	= map { $_ => 1 } map { @{ $_->in_scope_variables } } @plans;
+		return keys %vars;
+	}
 }
 
-package Attean::API::Planner 0.004 {
+package Attean::API::Plan::Join 0.007 {
+	use Moo::Role;
+	use Types::Standard qw(CodeRef);
+	use namespace::clean;
+	use Types::Standard qw(ArrayRef Str ConsumerOf Bool);
+	with 'Attean::API::Plan', 'Attean::API::BinaryQueryTree';
+	has 'join_variables' => (is => 'ro', isa => ArrayRef[Str], required => 1);
+	has 'anti' => (is => 'ro', isa => Bool, default => 0);	# is this an anti-join
+	has 'left' => (is => 'ro', isa => Bool, default => 0);	# is this a left, outer-join
+	
+	# if this is a left, outer-join, this is the filter expression that acts as part of the join operation (see the SPARQL semantics for LeftJoin for more details)
+	has 'expression' => (is => 'ro', isa => ConsumerOf['Attean::API::Expression'], required => 0, default => sub { Attean::ValueExpression->new( value => Attean::Literal->true ) });
+
+	around 'BUILDARGS' => sub {
+		my $orig		= shift;
+		my $class		= shift;
+		my %args		= @_;
+		my @vars		=  Attean::API::Plan->in_scope_variables_union( @{ $args{children} } );
+		
+		if (exists $args{in_scope_variables}) {
+			Carp::confess "in_scope_variables is computed automatically, and must not be specified in the $class constructor";
+		}
+		$args{in_scope_variables}	= [@vars];
+
+		return $orig->( $class, %args );
+	}
+	
+}
+
+package Attean::API::Planner 0.007 {
 	use Moo::Role;
 	use Types::Standard qw(CodeRef);
 	use namespace::clean;
@@ -84,7 +120,7 @@ package Attean::API::Planner 0.004 {
 	requires 'plan_for_algebra'; # plan_for_algebra($algebra, $model, \@default_graphs)
 }
 
-package Attean::API::CostPlanner 0.004 {
+package Attean::API::CostPlanner 0.007 {
 	use Moo::Role;
 	use Types::Standard qw(CodeRef);
 	use namespace::clean;
