@@ -7,7 +7,7 @@ Attean::API::Query - Utility package defining query-related roles
 
 =head1 VERSION
 
-This document describes Attean::API::Query version 0.005
+This document describes Attean::API::Query version 0.007
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,7 @@ This is a utility package for defining query-related roles:
 
 =cut
 
-package Attean::API::DirectedAcyclicGraph 0.005 {
+package Attean::API::DirectedAcyclicGraph 0.007 {
 	use Moo::Role;
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -101,8 +101,6 @@ package Attean::API::DirectedAcyclicGraph 0.005 {
 		foreach my $type (@types) {
 			delete $classes{$type};
 		}
-		use Data::Dumper;
-		warn Dumper(\%classes);
 		my @keys	= keys %classes;
 		return (scalar(@keys) == 0) ? 1 : 0;
 	}
@@ -142,13 +140,18 @@ package Attean::API::DirectedAcyclicGraph 0.005 {
 
 =cut
 
-package Attean::API::Algebra 0.005 {
+package Attean::API::Algebra 0.007 {
 	use Moo::Role;
 
 	requires 'as_sparql';
-
 	requires 'in_scope_variables';			# variables that will be in-scope after this operation is evaluated
 	
+	sub unary {
+		my $self	= shift;
+		return unless (scalar(@{ $self->children }) == 1);
+		return $self->children->[0];
+	}
+	
 	sub algebra_as_string {
 		my $self	= shift;
 		return "$self";
@@ -191,7 +194,7 @@ package Attean::API::Algebra 0.005 {
 
 =cut
 
-package Attean::API::QueryTree 0.005 {
+package Attean::API::QueryTree 0.007 {
 	use Moo::Role;
 	with 'Attean::API::DirectedAcyclicGraph';
 }
@@ -200,7 +203,7 @@ package Attean::API::QueryTree 0.005 {
 
 =cut
 
-package Attean::API::NullaryQueryTree 0.005 {
+package Attean::API::NullaryQueryTree 0.007 {
 	use Moo::Role;
 	sub arity { return 0 }
 	with 'Attean::API::QueryTree';
@@ -210,7 +213,7 @@ package Attean::API::NullaryQueryTree 0.005 {
 
 =cut
 
-package Attean::API::UnaryQueryTree 0.005 {
+package Attean::API::UnaryQueryTree 0.007 {
 	use Moo::Role;
 	sub arity { return 1 }
 	with 'Attean::API::QueryTree';
@@ -220,7 +223,7 @@ package Attean::API::UnaryQueryTree 0.005 {
 
 =cut
 
-package Attean::API::BinaryQueryTree 0.005 {
+package Attean::API::BinaryQueryTree 0.007 {
 	use Moo::Role;
 	sub arity { return 2 }
 	with 'Attean::API::QueryTree';
@@ -230,7 +233,7 @@ package Attean::API::BinaryQueryTree 0.005 {
 
 =cut
 
-package Attean::API::PropertyPath 0.005 {
+package Attean::API::PropertyPath 0.007 {
 	use Moo::Role;
 	with 'Attean::API::QueryTree';
 	requires 'as_string';
@@ -241,7 +244,7 @@ package Attean::API::PropertyPath 0.005 {
 
 =cut
 
-package Attean::API::UnaryPropertyPath 0.005 {
+package Attean::API::UnaryPropertyPath 0.007 {
 	use Moo::Role;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
@@ -271,7 +274,7 @@ package Attean::API::UnaryPropertyPath 0.005 {
 
 =cut
 
-package Attean::API::NaryPropertyPath 0.005 {
+package Attean::API::NaryPropertyPath 0.007 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -298,7 +301,7 @@ package Attean::API::NaryPropertyPath 0.005 {
 
 =cut
 
-package Attean::API::UnionScopeVariables 0.005 {
+package Attean::API::UnionScopeVariables 0.007 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -314,7 +317,7 @@ package Attean::API::UnionScopeVariables 0.005 {
 
 =cut
 
-package Attean::API::IntersectionScopeVariables 0.005 {
+package Attean::API::IntersectionScopeVariables 0.007 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
