@@ -7,7 +7,7 @@ Attean::Algebra - Representation of SPARQL algebra operators
 
 =head1 VERSION
 
-This document describes Attean::Algebra version 0.006
+This document describes Attean::Algebra version 0.007
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ use Attean::API::Query;
 
 =cut
 
-package Attean::Algebra::Join 0.006 {
+package Attean::Algebra::Join 0.007 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::BinaryQueryTree';
 	sub algebra_as_string { return 'Join' }
@@ -48,7 +48,7 @@ package Attean::Algebra::Join 0.006 {
 
 =cut
 
-package Attean::Algebra::LeftJoin 0.006 {
+package Attean::Algebra::LeftJoin 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::BinaryQueryTree';
@@ -85,7 +85,7 @@ package Attean::Algebra::LeftJoin 0.006 {
 
 =cut
 
-package Attean::Algebra::Filter 0.006 {
+package Attean::Algebra::Filter 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -113,7 +113,7 @@ package Attean::Algebra::Filter 0.006 {
 
 =cut
 
-package Attean::Algebra::Union 0.006 {
+package Attean::Algebra::Union 0.007 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::BinaryQueryTree';
 	sub algebra_as_string { return 'Union' }
@@ -137,7 +137,7 @@ package Attean::Algebra::Union 0.006 {
 
 =cut
 
-package Attean::Algebra::Graph 0.006 {
+package Attean::Algebra::Graph 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	sub in_scope_variables {
@@ -177,7 +177,7 @@ package Attean::Algebra::Graph 0.006 {
 
 =cut
 
-package Attean::Algebra::Extend 0.006 {
+package Attean::Algebra::Extend 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	sub in_scope_variables {
@@ -231,7 +231,7 @@ package Attean::Algebra::Extend 0.006 {
 
 =cut
 
-package Attean::Algebra::Minus 0.006 {
+package Attean::Algebra::Minus 0.007 {
 	use Moo;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -260,7 +260,7 @@ package Attean::Algebra::Minus 0.006 {
 
 =cut
 
-package Attean::Algebra::Distinct 0.006 {
+package Attean::Algebra::Distinct 0.007 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
 	sub algebra_as_string { return 'Distinct' }
@@ -286,7 +286,7 @@ package Attean::Algebra::Distinct 0.006 {
 
 =cut
 
-package Attean::Algebra::Reduced 0.006 {
+package Attean::Algebra::Reduced 0.007 {
 	use Moo;
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
 	sub algebra_as_string { return 'Reduced' }
@@ -312,7 +312,7 @@ package Attean::Algebra::Reduced 0.006 {
 
 =cut
 
-package Attean::Algebra::Slice 0.006 {
+package Attean::Algebra::Slice 0.007 {
 	use Moo;
 	use Types::Standard qw(Int);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -353,7 +353,7 @@ package Attean::Algebra::Slice 0.006 {
 
 =cut
 
-package Attean::Algebra::Project 0.006 {
+package Attean::Algebra::Project 0.007 {
 	use Moo;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -412,7 +412,7 @@ package Attean::Algebra::Project 0.006 {
 
 =cut
 
-package Attean::Algebra::Comparator 0.006 {
+package Attean::Algebra::Comparator 0.007 {
 	use Moo;
 	use Types::Standard qw(Bool ConsumerOf);
 	has 'ascending' => (is => 'ro', isa => Bool, default => 1);
@@ -421,7 +421,7 @@ package Attean::Algebra::Comparator 0.006 {
 	sub as_string {
 		my $self	= shift;
 		if ($self->ascending) {
-			return $self->expression->as_string;
+			return 'ASC(' . $self->expression->as_string . ')';
 		} else {
 			return 'DESC(' . $self->expression->as_string . ')';
 		}
@@ -440,7 +440,7 @@ package Attean::Algebra::Comparator 0.006 {
 
 =cut
 
-package Attean::Algebra::OrderBy 0.006 {
+package Attean::Algebra::OrderBy 0.007 {
 	use Moo;
 	use Types::Standard qw(ArrayRef InstanceOf);
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -469,7 +469,7 @@ package Attean::Algebra::OrderBy 0.006 {
 
 =cut
 
-package Attean::Algebra::BGP 0.006 {
+package Attean::Algebra::BGP 0.007 {
 	use Moo;
 	use Attean::RDF;
 	use Set::Scalar;
@@ -538,7 +538,7 @@ package Attean::Algebra::BGP 0.006 {
 
 =cut
 
-package Attean::Algebra::Service 0.006 {
+package Attean::Algebra::Service 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf Bool);
 	sub algebra_as_string {
@@ -569,7 +569,7 @@ package Attean::Algebra::Service 0.006 {
 
 =cut
 
-package Attean::Algebra::Path 0.006 {
+package Attean::Algebra::Path 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	sub in_scope_variables {
@@ -603,7 +603,7 @@ package Attean::Algebra::Path 0.006 {
 
 =cut
 
-package Attean::Algebra::Group 0.006 {
+package Attean::Algebra::Group 0.007 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	sub in_scope_variables {
@@ -669,7 +669,7 @@ package Attean::Algebra::Group 0.006 {
 
 =cut
 
-package Attean::Algebra::NegatedPropertySet 0.006 {
+package Attean::Algebra::NegatedPropertySet 0.007 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	with 'Attean::API::PropertyPath';
@@ -690,7 +690,7 @@ package Attean::Algebra::NegatedPropertySet 0.006 {
 
 =cut
 
-package Attean::Algebra::PredicatePath 0.006 {
+package Attean::Algebra::PredicatePath 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::PropertyPath';
@@ -714,7 +714,7 @@ package Attean::Algebra::PredicatePath 0.006 {
 
 =cut
 
-package Attean::Algebra::InversePath 0.006 {
+package Attean::Algebra::InversePath 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -730,7 +730,7 @@ package Attean::Algebra::InversePath 0.006 {
 
 =cut
 
-package Attean::Algebra::SequencePath 0.006 {
+package Attean::Algebra::SequencePath 0.007 {
 	use Moo;
 	with 'Attean::API::NaryPropertyPath';
 	sub separator { return "/" }
@@ -745,7 +745,7 @@ package Attean::Algebra::SequencePath 0.006 {
 
 =cut
 
-package Attean::Algebra::AlternativePath 0.006 {
+package Attean::Algebra::AlternativePath 0.007 {
 	use Moo;
 	with 'Attean::API::NaryPropertyPath';
 	sub separator { return "|" }
@@ -760,7 +760,7 @@ package Attean::Algebra::AlternativePath 0.006 {
 
 =cut
 
-package Attean::Algebra::ZeroOrMorePath 0.006 {
+package Attean::Algebra::ZeroOrMorePath 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -776,7 +776,7 @@ package Attean::Algebra::ZeroOrMorePath 0.006 {
 
 =cut
 
-package Attean::Algebra::OneOrMorePath 0.006 {
+package Attean::Algebra::OneOrMorePath 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -792,7 +792,7 @@ package Attean::Algebra::OneOrMorePath 0.006 {
 
 =cut
 
-package Attean::Algebra::ZeroOrOnePath 0.006 {
+package Attean::Algebra::ZeroOrOnePath 0.007 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	with 'Attean::API::UnaryPropertyPath';
@@ -808,7 +808,7 @@ package Attean::Algebra::ZeroOrOnePath 0.006 {
 
 =cut
 
-package Attean::Algebra::Table 0.006 {
+package Attean::Algebra::Table 0.007 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -841,7 +841,7 @@ package Attean::Algebra::Table 0.006 {
 
 =cut
 
-package Attean::Algebra::Ask 0.006 {
+package Attean::Algebra::Ask 0.007 {
 	use Moo;
 	sub in_scope_variables { return; }
 	with 'Attean::API::Algebra', 'Attean::API::UnaryQueryTree';
@@ -863,7 +863,7 @@ package Attean::Algebra::Ask 0.006 {
 
 =cut
 
-package Attean::Algebra::Construct 0.006 {
+package Attean::Algebra::Construct 0.007 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	has 'triples' => (is => 'ro', isa => ArrayRef[ConsumerOf['Attean::API::TriplePattern']]);
