@@ -7,7 +7,7 @@ Attean::IDPQueryPlanner - Iterative dynamic programming query planner
 
 =head1 VERSION
 
-This document describes Attean::IDPQueryPlanner version 0.006
+This document describes Attean::IDPQueryPlanner version 0.007
 
 =head1 SYNOPSIS
 
@@ -34,7 +34,7 @@ use Attean::Algebra;
 use Attean::Plan;
 use Attean::Expression;
 
-package Attean::IDPQueryPlanner 0.006 {
+package Attean::IDPQueryPlanner 0.007 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::RDF;
@@ -141,10 +141,10 @@ the supplied C<< $active_graph >>.
 					my $cmps	= $p->ordered;
 					if ($self->_comparators_are_stable_and_cover_vars($cmps, @vars)) {
 						# the plan has a stable ordering which covers all the variables, so we can just uniq the iterator
-						push(@dist, Attean::Plan::Unique->new(children => [$p], distinct => 1, in_scope_variables => $p->in_scope_variables, ordered => $p->ordered));
+						push(@dist, Attean::Plan::Unique->new(children => [$p], distinct => 1, ordered => $p->ordered));
 					} else {
 						# TODO: if the plan isn't distinct, but is ordered, we can use a batched implementation
-						push(@dist, Attean::Plan::HashDistinct->new(children => [$p], distinct => 1, in_scope_variables => $p->in_scope_variables, ordered => $p->ordered));
+						push(@dist, Attean::Plan::HashDistinct->new(children => [$p], distinct => 1, ordered => $p->ordered));
 					}
 				}
 			}
@@ -161,13 +161,14 @@ the supplied C<< $active_graph >>.
 				my $distinct	= $plan->distinct;
 				my $ordered		= $plan->ordered;
 				if ($expr->isa('Attean::ValueExpression') and $expr->value->does('Attean::API::Variable')) {
-					my $filtered	= Attean::Plan::EBVFilter->new(children => [$plan], variable => $expr->value->value, distinct => $distinct, in_scope_variables => $plan->in_scope_variables, ordered => $ordered);
+					my $filtered	= Attean::Plan::EBVFilter->new(children => [$plan], variable => $expr->value->value, distinct => $distinct, ordered => $ordered);
 					push(@plans, $filtered);
 				} else {
 					my @vars		= ($var);
+					my @inscope		= ($var, @{ $plan->in_scope_variables });
 					my @pvars		= map { Attean::Variable->new($_) } @{ $plan->in_scope_variables };
-					my $extend		= Attean::Plan::Extend->new(children => [$plan], expressions => \%exprs, distinct => 0, in_scope_variables => [@vars, $var], ordered => $ordered);
-					my $filtered	= Attean::Plan::EBVFilter->new(children => [$extend], variable => $var, distinct => 0, in_scope_variables => \@vars, ordered => $ordered);
+					my $extend		= Attean::Plan::Extend->new(children => [$plan], expressions => \%exprs, distinct => 0, ordered => $ordered);
+					my $filtered	= Attean::Plan::EBVFilter->new(children => [$extend], variable => $var, distinct => 0, ordered => $ordered);
 					my $proj		= $self->new_projection($filtered, $distinct, @{ $plan->in_scope_variables });
 					push(@plans, $proj);
 				}
@@ -176,26 +177,28 @@ the supplied C<< $active_graph >>.
 		} elsif ($algebra->isa('Attean::Algebra::OrderBy')) {
 			# TODO: no-op if already ordered
 			my @cmps	= @{ $algebra->comparators };
-			my %ascending;
-			my %exprs;
-			my @svars;
-			foreach my $i (0 .. $#cmps) {
-				my $var	= $self->new_temporary('order');
-				my $cmp	= $cmps[$i];
-				push(@svars, $var);
-				$ascending{$var}	= $cmp->ascending;
-				$exprs{$var}		= $cmp->expression;
-			}
-			
+			my ($exprs, $ascending, $svars)	= $self->_order_by($algebra);
 			my @plans;
 			foreach my $plan ($self->plans_for_algebra($child, $model, $active_graphs, $default_graphs, interesting_order => $algebra->comparators, @_)) {
 				my $distinct	= $plan->distinct;
-				my @vars	= (@{ $plan->in_scope_variables }, keys %exprs);
-				my @pvars	= map { Attean::Variable->new($_) } @{ $plan->in_scope_variables };
-				my $extend	= Attean::Plan::Extend->new(children => [$plan], expressions => \%exprs, distinct => 0, in_scope_variables => \@vars, ordered => $plan->ordered);
-				my $ordered	= Attean::Plan::OrderBy->new(children => [$extend], variables => \@svars, ascending => \%ascending, distinct => 0, in_scope_variables => \@vars, ordered => \@cmps);
-				my $proj	= $self->new_projection($ordered, $distinct, @{ $plan->in_scope_variables });
-				push(@plans, $proj);
+
+				if (scalar(@cmps) == 1 and $cmps[0]->expression->isa('Attean::ValueExpression') and $cmps[0]->expression->value->does('Attean::API::Variable')) {
+					# TODO: extend this to handle more than one comparator, so long as they are *all* just variables (and not complex expressions)
+					# If we're sorting by just a variable name, don't bother creating new variables for the sort expressions, use the underlying variable directy
+					my @vars	= @{ $plan->in_scope_variables };
+					my @pvars	= map { Attean::Variable->new($_) } @{ $plan->in_scope_variables };
+					my $var		= $cmps[0]->expression->value->value;
+					my $ascending	= { $var => $cmps[0]->ascending };
+					my $ordered	= Attean::Plan::OrderBy->new(children => [$plan], variables => [$var], ascending => $ascending, distinct => $distinct, ordered => \@cmps);
+					push(@plans, $ordered);
+				} else {
+					my @vars	= (@{ $plan->in_scope_variables }, keys %$exprs);
+					my @pvars	= map { Attean::Variable->new($_) } @{ $plan->in_scope_variables };
+					my $extend	= Attean::Plan::Extend->new(children => [$plan], expressions => $exprs, distinct => 0, ordered => $plan->ordered);
+					my $ordered	= Attean::Plan::OrderBy->new(children => [$extend], variables => $svars, ascending => $ascending, distinct => 0, ordered => \@cmps);
+					my $proj	= $self->new_projection($ordered, $distinct, @{ $plan->in_scope_variables });
+					push(@plans, $proj);
+				}
 			}
 			
 			return @plans;
@@ -237,7 +240,7 @@ the supplied C<< $active_graph >>.
 					my %exprs	= ($gvar => Attean::ValueExpression->new(value => $graph));
 					# TODO: rewrite $child pattern here to replace any occurrences of the variable $gvar to $graph
 					my @plans	= map {
-						Attean::Plan::Extend->new(children => [$_], expressions => \%exprs, distinct => 0, in_scope_variables => \@vars, ordered => $_->ordered);
+						Attean::Plan::Extend->new(children => [$_], expressions => \%exprs, distinct => 0, ordered => $_->ordered);
 					} $self->plans_for_algebra($child, $model, [$graph], $default_graphs, @_);
 					push(@branches, \@plans);
 				}
@@ -245,7 +248,7 @@ the supplied C<< $active_graph >>.
 				if (scalar(@branches) == 1) {
 					@plans	= @{ shift(@branches) };
 				} else {
-					cartesian { push(@plans, Attean::Plan::Union->new(children => [@_], distinct => 0, in_scope_variables => \@vars, ordered => [])) } @branches;
+					cartesian { push(@plans, Attean::Plan::Union->new(children => [@_], distinct => 0, ordered => [])) } @branches;
 				}
 				return @plans;
 			}
@@ -253,7 +256,7 @@ the supplied C<< $active_graph >>.
 			my $rows	= $algebra->rows;
 			my $vars	= $algebra->variables;
 			my @vars	= map { $_->value } @{ $vars };
-			my $plan	= Attean::Plan::Table->new( variables => $vars, rows => $rows, distinct => 0, in_scope_variables => \@vars, ordered => [] );
+			my $plan	= Attean::Plan::Table->new( variables => $vars, rows => $rows, distinct => 0, ordered => [] );
 			return $plan;
 		} elsif ($algebra->isa('Attean::Algebra::Service')) {
 			my $endpoint	= $algebra->endpoint;
@@ -265,10 +268,39 @@ the supplied C<< $active_graph >>.
 		} elsif ($algebra->isa('Attean::Algebra::Slice')) {
 			my $limit	= $algebra->limit;
 			my $offset	= $algebra->offset;
+			if (my $child = $algebra->unary) {
+				my $vars;
+				if ($child->isa('Attean::Algebra::Project')) {
+					$vars		= $child->variables;
+					$child		= $child->unary;
+				}
+				
+				if ($child->isa('Attean::Algebra::OrderBy')) {
+					my $count	= $limit + $offset;
+					my @cmps	= @{ $child->comparators };
+					my ($exprs, $ascending, $svars)	= $self->_order_by($child);
+					my @plans;
+					foreach my $plan ($self->plans_for_algebra($child->children->[0], $model, $active_graphs, $default_graphs, @_)) {
+						my @vars	= @{ $plan->in_scope_variables };
+						my @evars	= (@vars, keys %$exprs);
+						my $extend	= Attean::Plan::Extend->new(children => [$plan], expressions => $exprs, distinct => 0, ordered => $plan->ordered);
+						my $ordered	= Attean::Plan::HeapSort->new(children => [$extend], limit => $count, variables => $svars, ascending => $ascending, distinct => $plan->distinct, ordered => \@cmps);
+						my $proj	= $self->new_projection($ordered, $plan->distinct, @{ $plan->in_scope_variables });
+						if ($offset) {
+							$proj	= Attean::Plan::Slice->new(children => [$proj], offset => $offset, distinct => $proj->distinct, ordered => $proj->ordered);
+						}
+						push(@plans, $proj);
+					}
+					return @plans;
+				}
+			}
+			
+			
+			
 			my @plans;
 			foreach my $plan ($self->plans_for_algebra($child, $model, $active_graphs, $default_graphs, @_)) {
 				my $vars	= $plan->in_scope_variables;
-				push(@plans, Attean::Plan::Slice->new(children => [$plan], limit => $limit, offset => $offset, distinct => $plan->distinct, in_scope_variables => $vars, ordered => $plan->ordered));
+				push(@plans, Attean::Plan::Slice->new(children => [$plan], limit => $limit, offset => $offset, distinct => $plan->distinct, ordered => $plan->ordered));
 			}
 			return @plans;
 		} elsif ($algebra->isa('Attean::Algebra::Union')) {
@@ -278,7 +310,7 @@ the supplied C<< $active_graph >>.
 
 			my @plans;
 			cartesian {
-				push(@plans, Attean::Plan::Union->new(children => \@_, distinct => 0, in_scope_variables => \@vars, ordered => []))
+				push(@plans, Attean::Plan::Union->new(children => \@_, distinct => 0, ordered => []))
 			} @plansets;
 			return @plans;
 		} elsif ($algebra->isa('Attean::Algebra::Extend')) {
@@ -289,14 +321,14 @@ the supplied C<< $active_graph >>.
 
 			my @plans;
 			foreach my $plan ($self->plans_for_algebra($child, $model, $active_graphs, $default_graphs, @_)) {
-				my $extend		= Attean::Plan::Extend->new(children => [$plan], expressions => \%exprs, distinct => 0, in_scope_variables => [@vars, $var], ordered => $plan->ordered);
+				my $extend		= Attean::Plan::Extend->new(children => [$plan], expressions => \%exprs, distinct => 0, ordered => $plan->ordered);
 				push(@plans, $extend);
 			}
 			return @plans;
 		} elsif ($algebra->isa('Attean::Algebra::Ask')) {
 			my @plans;
 			foreach my $plan ($self->plans_for_algebra($child, $model, $active_graphs, $default_graphs, @_)) {
-				return Attean::Plan::Exists->new(children => [$plan], distinct => 1, in_scope_variables => [], ordered => []);
+				return Attean::Plan::Exists->new(children => [$plan], distinct => 1, ordered => []);
 			}
 			return @plans;
 		} elsif ($algebra->isa('Attean::Algebra::Group')) {
@@ -332,7 +364,7 @@ the supplied C<< $active_graph >>.
 			push(@porder, $cmp);
 		}
 		
-		return Attean::Plan::Project->new(children => [$plan], variables => \@pvars, distinct => $distinct, in_scope_variables => \@vars, ordered => \@porder);
+		return Attean::Plan::Project->new(children => [$plan], variables => \@pvars, distinct => $distinct, ordered => \@porder);
 	}
 
 =item C<< bgp_join_plans( $bgp, $model, \@active_graphs, \@default_graphs, \@interesting_order, \@plansA, \@plansB, ... ) >>
@@ -389,7 +421,7 @@ triple participating in the join.
 		} else {
 			# The empty BGP is a special case -- it results in a single join-identity result
 			my $r		= Attean::Result->new( bindings => {} );
-			my $plan	= Attean::Plan::Table->new( rows => [$r], variables => [], distinct => 1, in_scope_variables => [], ordered => [] );
+			my $plan	= Attean::Plan::Table->new( rows => [$r], variables => [], distinct => 1, ordered => [] );
 			return $plan;
 		}
 	}
@@ -580,24 +612,24 @@ sub-plan participating in the join.
 				my @join_vars	= keys %join_vars;
 				
 				if ($left) {
-					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$lhs, $rhs], left => 1, expression => $expr, join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => $lhs->ordered));
+					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$lhs, $rhs], left => 1, expression => $expr, join_variables => \@join_vars, distinct => 0, ordered => $lhs->ordered));
 					if (scalar(@join_vars) > 0) {
-						push(@plans, Attean::Plan::HashJoin->new(children => [$lhs, $rhs], left => 1, expression => $expr, join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => []));
+						push(@plans, Attean::Plan::HashJoin->new(children => [$lhs, $rhs], left => 1, expression => $expr, join_variables => \@join_vars, distinct => 0, ordered => []));
 					}
 				} elsif ($minus) {
-					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$lhs, $rhs], anti => 1, join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => $lhs->ordered));
+					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$lhs, $rhs], anti => 1, join_variables => \@join_vars, distinct => 0, ordered => $lhs->ordered));
 					if (scalar(@join_vars) > 0) {
-						push(@plans, Attean::Plan::HashJoin->new(children => [$lhs, $rhs], anti => 1, join_variables => \@join_vars, join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => []));
+						push(@plans, Attean::Plan::HashJoin->new(children => [$lhs, $rhs], anti => 1, join_variables => \@join_vars, join_variables => \@join_vars, distinct => 0, ordered => []));
 					}
 				} else {
 					# nested loop joins work in all cases
-					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$lhs, $rhs], join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => $lhs->ordered));
-					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$rhs, $lhs], join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => $rhs->ordered));
+					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$lhs, $rhs], join_variables => \@join_vars, distinct => 0, ordered => $lhs->ordered));
+					push(@plans, Attean::Plan::NestedLoopJoin->new(children => [$rhs, $lhs], join_variables => \@join_vars, distinct => 0, ordered => $rhs->ordered));
 			
 					if (scalar(@join_vars) > 0) {
 						# if there's shared variables (hopefully), we can also use a hash join
-						push(@plans, Attean::Plan::HashJoin->new(children => [$lhs, $rhs], join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => []));
-						push(@plans, Attean::Plan::HashJoin->new(children => [$rhs, $lhs], join_variables => \@join_vars, distinct => 0, in_scope_variables => [keys %vars], ordered => []));
+						push(@plans, Attean::Plan::HashJoin->new(children => [$lhs, $rhs], join_variables => \@join_vars, distinct => 0, ordered => []));
+						push(@plans, Attean::Plan::HashJoin->new(children => [$rhs, $lhs], join_variables => \@join_vars, distinct => 0, ordered => []));
 					}
 				}
 			}
@@ -695,7 +727,25 @@ sub-plan participating in the join.
 		my @keys	= keys %unseen;
 		return (scalar(@keys) == 0);
 	}
-
+	
+	sub _order_by {
+		my $self	= shift;
+		my $algebra	= shift;
+		my ($exprs, $ascending, $svars);
+		my @cmps	= @{ $algebra->comparators };
+		my %ascending;
+		my %exprs;
+		my @svars;
+		foreach my $i (0 .. $#cmps) {
+			my $var	= $self->new_temporary('order');
+			my $cmp	= $cmps[$i];
+			push(@svars, $var);
+			$ascending{$var}	= $cmp->ascending;
+			$exprs{$var}		= $cmp->expression;
+		}
+		return (\%exprs, \%ascending, \@svars);
+	}
+	
 # The below function finds a number to aid sorting
 # It takes into account Heuristic 1 and 4 of the HSP paper, see REFERENCES
 # as well as that it was noted in the text that rdf:type is usually less selective.
